@@ -17,7 +17,7 @@ from shell:
 
 =head1 DESCRIPTION
 
-Loads a given module and reports it's location and version. 
+Loads a given module and reports it's location and version.
 
 The similar function can be achieved via:
 
@@ -32,7 +32,7 @@ The similar function can be achieved via:
 use warnings;
 use strict;
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 use File::Spec;
 
@@ -67,7 +67,7 @@ C<$module_name> can be either C<Some::Module::Name> or C<Some/Module/Name.pm>
 sub find {
 	my $module_name = shift;
 	my $module_filename;
-	
+
 	if ($module_name =~ m/\.pm$/xms) {
 		$module_name     = substr($module_name, 0, -3);
 		$module_name     =~ s{[/\\]}{::}g;
@@ -76,10 +76,10 @@ sub find {
 	$module_filename        = $module_name.'.pm';
 	my $module_inc_filename = join('/', split('::', $module_filename));
 	$module_filename        = File::Spec->catfile(split('::', $module_filename));
-	
+
 	eval "use $module_name;";
 	my $filename = $INC{$module_inc_filename};
-	
+
 	# if the filename is not in %INC then try to search the @INC folders
 	if (not $filename) {
 		foreach my $inc_path (@INC) {
@@ -89,10 +89,10 @@ sub find {
 		}
 		return;
 	}
-	
+
 	# MSWin32 has unix / in the %INC folder paths, so recreate the filename
 	$filename = File::Spec->catfile(split(m{[/\\]}, $filename));
-	
+
 	if (wantarray) {
 		my $version  = eval { $module_name->VERSION };
 		return ($filename, (defined $version ? $version : ()));
@@ -111,6 +111,20 @@ __END__
 L<http://perlmonks.org/?node=whichpm>, L<pmpath|http://search.cpan.org/perldoc?pmpath>,
 L<Module::InstalledVersion>, L<Module::Info>
 
+=head1 AUTHOR
+
+Jozef Kutej
+
+=head1 CONTRIBUTORS
+
+The following people have contributed to the File::is by committing their
+code, sending patches, reporting bugs, asking questions, suggesting useful
+advises, nitpicking, chatting on IRC or commenting on my blog (in no particular
+order):
+
+	Jerrad Pierce
+	Skye Shaw
+
 =head1 LICENSE AND COPYRIGHT
 
 This program is free software; you can redistribute it and/or modify it
@@ -119,8 +133,4 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-=head1 AUTHOR
-
-Jozef Kutej
-
 =cut
